@@ -73,7 +73,10 @@ new ApiGatewayToSqs(scope: Construct, id: string, props: ApiGatewayToSqsProps);
 |:-------------|:----------------|-----------------|
 |apiGateway|[`api.RestApi`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-apigateway.RestApi.html)|Returns an instance of the API Gateway REST API created by the pattern.|
 |apiGatewayRole|[`iam.Role`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-iam.Role.html)|Returns an instance of the iam.Role created by the construct for API Gateway.|
+|apiGatewayCloudWatchRole|[`iam.Role`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-iam.Role.html)|Returns an instance of the iam.Role created by the construct for API Gateway for CloudWatch access.|
+|apiGatewayLogGroup|[`logs.LogGroup`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-logs.LogGroup.html)|Returns an instance of the LogGroup created by the construct for API Gateway access logging to CloudWatch.|
 |sqsQueue|[`sqs.Queue`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-sqs.Queue.html)|Returns an instance of the SQS queue created by the pattern.|
+|deadLetterQueue?|[`sqs.DeadLetterQueue`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-sqs.DeadLetterQueue.html)|Returns an instance of the DeadLetterQueue created by the pattern.|
 
 ## Sample API Usage
 
@@ -122,6 +125,7 @@ from ._jsii import *
 
 import aws_cdk.aws_apigateway
 import aws_cdk.aws_iam
+import aws_cdk.aws_logs
 import aws_cdk.aws_sqs
 import aws_cdk.core
 
@@ -148,7 +152,7 @@ class ApiGatewayToSqs(
         create_request_template: typing.Optional[str] = None,
         deploy_dead_letter_queue: typing.Optional[bool] = None,
         max_receive_count: typing.Optional[jsii.Number] = None,
-        queue_props: typing.Any = None,
+        queue_props: typing.Optional[aws_cdk.aws_sqs.QueueProps] = None,
     ) -> None:
         """
         :param scope: - represents the scope for all the resources.
@@ -187,6 +191,16 @@ class ApiGatewayToSqs(
     def api_gateway(self) -> aws_cdk.aws_apigateway.RestApi:
         return jsii.get(self, "apiGateway")
 
+    @builtins.property
+    @jsii.member(jsii_name="apiGatewayCloudWatchRole")
+    def api_gateway_cloud_watch_role(self) -> aws_cdk.aws_iam.Role:
+        return jsii.get(self, "apiGatewayCloudWatchRole")
+
+    @builtins.property
+    @jsii.member(jsii_name="apiGatewayLogGroup")
+    def api_gateway_log_group(self) -> aws_cdk.aws_logs.LogGroup:
+        return jsii.get(self, "apiGatewayLogGroup")
+
     @builtins.property
     @jsii.member(jsii_name="apiGatewayRole")
     def api_gateway_role(self) -> aws_cdk.aws_iam.Role:
@@ -197,6 +211,11 @@ class ApiGatewayToSqs(
     def sqs_queue(self) -> aws_cdk.aws_sqs.Queue:
         return jsii.get(self, "sqsQueue")
 
+    @builtins.property
+    @jsii.member(jsii_name="deadLetterQueue")
+    def dead_letter_queue(self) -> typing.Optional[aws_cdk.aws_sqs.DeadLetterQueue]:
+        return jsii.get(self, "deadLetterQueue")
+
 
 @jsii.data_type(
     jsii_type="@aws-solutions-constructs/aws-apigateway-sqs.ApiGatewayToSqsProps",
@@ -223,7 +242,7 @@ class ApiGatewayToSqsProps:
         create_request_template: typing.Optional[str] = None,
         deploy_dead_letter_queue: typing.Optional[bool] = None,
         max_receive_count: typing.Optional[jsii.Number] = None,
-        queue_props: typing.Any = None,
+        queue_props: typing.Optional[aws_cdk.aws_sqs.QueueProps] = None,
     ) -> None:
         """
         :param allow_create_operation: Whether to deploy an API Gateway Method for Create operations on the queue (i.e. sqs:SendMessage). Default: - false
@@ -238,6 +257,8 @@ class ApiGatewayToSqsProps:
         summary:
         :summary:: The properties for the ApiGatewayToSqs class.
         """
+        if isinstance(queue_props, dict):
+            queue_props = aws_cdk.aws_sqs.QueueProps(**queue_props)
         self._values = {}
         if allow_create_operation is not None:
             self._values["allow_create_operation"] = allow_create_operation
@@ -320,7 +341,7 @@ class ApiGatewayToSqsProps:
         return self._values.get("max_receive_count")
 
     @builtins.property
-    def queue_props(self) -> typing.Any:
+    def queue_props(self) -> typing.Optional[aws_cdk.aws_sqs.QueueProps]:
         """Optional user-provided props to override the default props for the queue.
 
         default
